diff src/conversation.h @ 10246:a66cf83552dc

[gaim-migrate @ 11386] I changed gaim_find_conversation and gaim_find_conversation_with_account The first parameter is now one of GAIM_CONV_IM, GAIM_CONV_CHAT or GAIM_CONV_ANY. Unfortunately, this changes a bajillion files. Please look over this and make sure I use the correct type everywhere. Especially in Novell and MSN, and somewhat in SILC. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Tue, 23 Nov 2004 06:14:15 +0000
parents 50c1724d5e59
children bbf738a0ce7b
line wrap: on
line diff
--- a/src/conversation.h	Tue Nov 23 05:53:59 2004 +0000
+++ b/src/conversation.h	Tue Nov 23 06:14:15 2004 +0000
@@ -47,7 +47,8 @@
 	GAIM_CONV_UNKNOWN = 0, /**< Unknown conversation type. */
 	GAIM_CONV_IM,          /**< Instant Message.           */
 	GAIM_CONV_CHAT,        /**< Chat room.                 */
-	GAIM_CONV_MISC         /**< A misc. conversation.      */
+	GAIM_CONV_MISC,        /**< A misc. conversation.      */
+	GAIM_CONV_ANY          /**< Any type of conversation.  */
 
 } GaimConversationType;
 
@@ -783,24 +784,30 @@
 GList *gaim_get_chats(void);
 
 /**
- * Finds the conversation with the specified name.
+ * Finds the conversation with the specified type and name.  In most
+ * cases you should use gaim_find_conversation_with_account() instead
+ * of this.
  *
+ * @param type The type of the conversation.
  * @param name The name of the conversation.
  *
  * @return The conversation if found, or @c NULL otherwise.
  */
-GaimConversation *gaim_find_conversation(const char *name);
+GaimConversation *gaim_find_conversation(GaimConversationType type,
+										 const char *name);
 
 /**
  * Finds a conversation with the specified name and user.
  *
+ * @param type The type of the conversation.
  * @param name The name of the conversation.
  * @param account The gaim_account associated with the conversation.
  *
  * @return The conversation if found, or @c NULL otherwise.
  */
 GaimConversation *gaim_find_conversation_with_account(
-		const char *name, const GaimAccount *account);
+		GaimConversationType type, const char *name,
+		const GaimAccount *account);
 
 /**
  * Writes to a conversation window.
@@ -783,24 +784,30 @@
 
 /**
- * Finds a conversation with the specified name and user.
+ * Finds a conversation with the specified type, name, and Gaim account.
  *